@@ -4,6 +4,7 @@
 #include <netinet/ether.h>
 #include <netinet/if_ether.h>
 #include <netinet/ip.h>
+#include <netinet/tcp.h>
 #include <pthread.h>
 #include <sys/time.h>
 #include <unistd.h>
@@ -53,7 +54,7 @@ CRecord::CRecord(CRecord *cr)
 	} else {
 		llDst_m = 0;
 	}
-#if 1
+
 	srcSerial_m = cr->srcSerial_m;
 	dstSerial_m = cr->dstSerial_m;
 	ip_src_m = cr->ip_src_m;
@@ -61,16 +62,9 @@ CRecord::CRecord(CRecord *cr)
 	ip_proto_m = cr->ip_proto_m;
 	volume_m = cr->volume_m;
 	packets_m = cr->packets_m;
-#endif
-	// TODO: FIX proper copier
-	if (cr->dataBlockList_m.size() == 1) {
-		 dataBlockList_m.push_back(new CDataBlock(cr->dataBlockList_m.front()));
-		//cerr << "copy" << endl;
-	} else if (cr->dataBlockList_m.size() != 0) {
-		//cerr << "single copy here only supported" << endl;
-	 } else {
-		//cerr << "copy with no data " << dataBlockList_m.size() << endl;
-	 }
+
+	data_ += cr->data_;
+
 	char	src_ip_char[inet_to_stringSize];
 	inet_to_char(ip_src_m, src_ip_char);
 	char	dst_ip_char[inet_to_stringSize];
@@ -82,12 +76,13 @@ CRecord::CRecord(CRecord *cr)
 				+ protocol_to_string(ip_proto_m);
 }
 
-CRecord::CRecord(const struct my_ip *ip, int volume, const char *llSrc, const char *llDst)
+CRecord::CRecord(const struct ip *ip, int port_src, int port_dst,
+				int volume, const char *llSrc, const char *llDst, string data)
 		: ip_src_m(ip->ip_src), srcSerial_m(-1), dstSerial_m(-1), ip_dst_m(ip->ip_dst),
-				ip_proto_m(ip->ip_p), volume_m(volume), packets_m(1)
+				ip_proto_m(ip->ip_p), volume_m(volume), packets_m(1), data_(data)
 {
-	port_src_m =	ntohs(ip->port_src);
-	port_dst_m =	ntohs(ip->port_dst);
+	port_src_m =	ntohs(port_src);
+	port_dst_m =	ntohs(port_dst);
 	memset(&lastUpdate_, 0, sizeof (lastUpdate_));
 	memset(&lastUpdate_, 0, sizeof (firstUpdate_));
 	if (llSrc != 0) {
@@ -113,8 +108,6 @@ CRecord::CRecord(const struct my_ip *ip, int volume, const char *llSrc, const ch
 				+ port_to_string(port_src_m)
 				+ port_to_string(port_dst_m)
 				+ protocol_to_string(ip_proto_m);
-//	memset(&dataBlockList_m, 0, sizeof (dataBlockList_m));
-//	cerr << "new from parts" << endl;
 }
 
 CRecord::~CRecord()
@@ -127,14 +120,6 @@ CRecord::~CRecord()
 		 //printf("delete llDst %x\n", llDst_m);
 		delete [] llDst_m;
 	}
-	dataBlockList_m.clear();
-//	cout << "deleting CDataBlock list " << dataBlockList_m.size() << endl;
-	for (CDataBlockList::iterator it = dataBlockList_m.begin(); it != dataBlockList_m.end(); it++) {
-		CDataBlock *cdb = *it;
-		dataBlockList_m.erase(it);
-//		cout << "deleting CDataBlock" << endl;
-		delete cdb;
-	}
 }
 
 
