@@ -1,23 +1,3 @@
-struct CDataBlock {
-	const unsigned char	*data_m;
-	int	size_m;
-	CDataBlock(int dbSize, const unsigned char *dataBlock) : size_m(dbSize) {
-		data_m = new unsigned char[dbSize];
-		memcpy((unsigned char *)data_m, dataBlock, dbSize);
-	}
-	CDataBlock(CDataBlock *cr) {
-		size_m = cr->size_m;
-		data_m = new unsigned char[cr->size_m];
-		memcpy((unsigned char *)data_m, cr->data_m, cr->size_m);
-	}
-	~CDataBlock() {
-		cout << "deleteing datablock" << endl;
-		delete data_m;
-	}
-};
-
-typedef list<CDataBlock *>	CDataBlockList;
-typedef CDataBlockList::iterator	CDataBlockListIter;
 
 
 struct CRecord : public PrioRecord {
@@ -32,11 +12,11 @@ struct CRecord : public PrioRecord {
 	int packets_m;
 	char *llSrc_m;
 	char *llDst_m;
-	CDataBlockList	dataBlockList_m;
+	string	data_;
 	string	key_;
 
 	CRecord(CRecord *cr);
-    CRecord(const struct my_ip *ip, int volume, const char *llSrc, const char *llDst);
+    CRecord(const struct ip *ip, int port_src, int port_dst, int volume, const char *llSrc, const char *llDst, string data);
     ~CRecord();
 	// overrides for priority Q class
 	string  MakeKey() { return key_; }
@@ -47,6 +27,7 @@ struct CRecord : public PrioRecord {
 		CRecord	*cr = static_cast<CRecord *>(pr);
 		volume_m += cr->volume_m;
 		packets_m++; 
+		data_ += cr->data_;
 	}
 	CRecord *create() {
 		return new CRecord(this);
