@@ -1,4 +1,4 @@
 
 extern void	SQLConnect(char *connectionInfo);
-extern bool	SQlSaveRecord(class CRecord *cr, string interfacename);
+extern bool	SQlSaveRecord(struct CRecord *cr, string interfaceName,  struct timeval *now);
 extern int	SQLGetDNS(string resolvedName, const struct in_addr& ip, const char *mac);
