@@ -4,6 +4,9 @@
 #include <netinet/ether.h>
 #include <netinet/if_ether.h>
 #include <netinet/ip.h>
+#include <netinet/tcp.h>
+#include <netinet/udp.h>
+#include <netinet/ip_icmp.h>
 #include <pthread.h>
 #include <sys/time.h>
 #include <unistd.h>
@@ -57,15 +60,11 @@ int	FlushDataToDb(RTable  *acom, int sinceInSeconds) {
 
 		cr->srcSerial_m = acom->FindHostFromIP(cr->ip_src_m, cr->llSrc_m);
 		cr->dstSerial_m = acom->FindHostFromIP(cr->ip_dst_m, cr->llDst_m);
-		//cr->Print(cout);
-		if (SQlSaveRecord(cr, acom->Get_InterfaceName(), sinceInSeconds == 0 ? &now : 0) != 0) {
-			//cout << "OK" << endl;
+		if (SQlSaveRecord(cr, acom->Get_InterfaceName(), sinceInSeconds == 0 ? &now : 0) == true) {
 			seen++;
 			crl->erase(prev);
 			delete cr;
-		}  else {
-			cout << "NOT OK" << endl;
-		}
+		} 
 	}
 	delete crl;
 	return seen;
@@ -124,54 +123,54 @@ static void    *FullFlushyThread(void *arg)
 u_char *handle_IP(u_char *args, const struct pcap_pkthdr *pkthdr, const u_char * packet, int hrdSize,
 	const char *llSrc, const char *llDst, bool save)
 {
-  const struct my_ip *ip;
-  u_int length = pkthdr->len;
-  u_int hlen = 0; 
-  u_int	off = 0;
-  u_int	version = 0;
-//  int i;
-
-  int len;
-
-/* jump pass the ethernet header */
-  ip = (struct my_ip *)(packet + hrdSize);
-  length -= hrdSize;
-
-/* check to see we have a packet of valid length */
-	if (length < sizeof (struct my_ip)) {
-		syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_INFO), "truncated ip of length %d", length);
-		return NULL;
-
-	}
-	len = ntohs(ip->ip_len);
-	hlen = IP_HL(ip);		/* header length */
-	version = IP_V(ip);		/* ip version */
-
-	/* check version */
-	if (version != 4) {
-		syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_INFO), "unsupported IP version %d", version);
+	const u_char *payload = packet + hrdSize;
+	struct ip	*iph = (struct ip *)payload;
+	int unsigned payload_offset;
+	int unsigned payload_length;
+	int		port_src;
+	int		port_dst;
+		
+	if (iph->ip_v != 4) {
+		syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_INFO), "unsupported IP version %d", iph->ip_v);
 		return NULL;
 	}
-
-	/* check header length */
-	if (hlen < 5) {
-		syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_INFO), "bad-hlen  %d", hlen);
+	switch (iph->ip_p) {
+	case IPPROTO_ICMP: {
+			struct icmphdr *icmp = (struct icmphdr *)(payload + (iph->ip_hl << 2));
+			payload_offset = (sizeof (struct icmphdr) + (iph->ip_hl << 2) );
+			payload_length = 0;
+			port_src = 0;
+			port_dst = 0;
+		}
+		break;
+	case IPPROTO_TCP: {
+			struct tcphdr *tcp = (struct tcphdr *)(payload + (iph->ip_hl << 2)); 
+			payload_offset = ((iph->ip_hl << 2) + (tcp->doff << 2));
+			payload_length = (unsigned int) ntohs(iph->ip_len) - ((iph->ip_hl << 2) + (tcp->doff << 2));
+			port_src = tcp->source;
+			port_dst = tcp->dest;
+		}
+		break;
+	case IPPROTO_UDP: {
+			struct udphdr *udp = (struct udphdr *)(payload + (iph->ip_hl << 2));
+			payload_offset = (sizeof (struct udphdr) + (iph->ip_hl << 2) );
+			payload_length = htons(udp->len) - sizeof (struct udphdr);
+			port_src = udp->source;
+			port_dst = udp->dest;
+		}
+		break;
+	default:
+		cerr << "Unsupported protocol '" << (int)iph->ip_p << "'" << endl;
 		return NULL;
 	}
+	CRecord	cr(iph, port_src, port_dst, pkthdr->len, llSrc, llDst,
+				save ? string((const char *)payload + payload_offset, payload_length) : string(""));
 
-	/* see if we have as much packet as we should */
-	if (length < len) {
-		syslog(LOG_MAKEPRI(LOG_DAEMON, LOG_INFO), "truncated IP - %d bytes missing", len - length);
-		return NULL;
-	}
-
-	RTable  *rt = (RTable *)args;
-
-	CRecord	cr(ip, pkthdr->len, llSrc, llDst);
-	rt->Accumulate(&cr, pkthdr->ts); //, save ? (int)length : -1, (unsigned char *)packet);
+	((RTable *)args)->Accumulate(&cr, pkthdr->ts);
 	return NULL;
 }
 
+
 #ifndef ETHER_HDRLEN
 #define ETHER_HDRLEN 14
 #endif
@@ -187,15 +186,12 @@ void my_callback(u_char *args, const struct pcap_pkthdr *pkthdr, const u_char *p
 //	rt->Get_DnsCache()->FlushOld();
 
 	if (secondaryFilterCompiled) {
-#if 0
 		if (bpf_filter(compiledSecondaryFilter.bf_insns,
 				(u_char *)packet,
 				pkthdr->len,
 				pkthdr->caplen) != 0) {
-			cout << "packet recognised by secondary filter" << endl;
-#endif
 			save = true;
-//		}
+		}
 	}
 	switch (rt->Get_DataLinkType()) {
 	case DLT_PPP:
@@ -297,7 +293,7 @@ int main(int argc, char *argv[])
 	int	sltime = 10;
 	int	numPackets = 10;
 	int	age = 120;
-	char	*connectionString = "usage@localhost";
+	char	*connectionString = "usage";
 	char	*filter = 0;
 	char	*secondaryFilter = 0;
 	int		dnsExpiryTime = 120;
